#
#	Library:	ddjSupportFunctions.py - Version: 1.0.0
#	Author:		Dario de Judicibus <ddj@mc.link.it> http://www.dejudicibus.it/psl/
#	Content:	DdJ's toolsbox for PainShop Pro 9.x and 10.x
#	History:
#	1.0 - Initial release
#

from JascApp import *
import JascUtils

# Global variables
LibraryVersion = 1.0

# Begin Translatable Strings
MsgNoDocument = "This script requires an open document."
MsgMustHaveSel = "You must have a selection to run this script."
# End Translatable Strings

# *******************************************************************************
#	Function:	 ddjSupportCheck
#	Purpose:	 Checks the current support function pack version. This will
#				 allow to detect support script pack version mismatch.
#	Returns:	 
#	Parameters:	 Environment - PSP environment
#				 nRequiredVersion - the minimum required version of the support pack
#				 nIdealVersion - the ideal version required to have the best results
#	Notes:		 
# ********************************************************************************
def ddjSupportCheck(Environment, nRequiredVersion, nIdealVersion):
	
	# If the current version is lower than required
	if (LibraryVersion < nRequiredVersion):
		App.Do( Environment, 'MsgBox', {
				'Buttons': App.Constants.MsgButtons.OK, 
				'Icon': App.Constants.MsgIcons.Stop, 
				'Text': 'This script requires DdJ support function pack v' + str(nRequiredVersion) + ' to run. Visit http://www.dejudicibus.it/psl/ to get the latest version.', 
				})
		return App.Constants.Boolean.false
	
	# The current version is at least equal to the required one
	else:
		# Is there a better version than the bare minimum?
		if (LibraryVersion < nIdealVersion):
		
			# Quiet warning using the script debug window
			print 'This script might work better with a newer DdJ support function pack v%d. Visit http://www.dejudicibus.it/psl/ to get the latest version.' % (nIdealVersion)
		return App.Constants.Boolean.true

# *******************************************************************************
#	Function:	 ddjPSPVersionCheck
#	Purpose:	 Checks the current Paint Shop Pro version. This will
#				 allow to detect major version mismatch.
#	Returns:	 
#	Parameters:	 Environment - PSP environment
#				 nRequiredVersion - the minimum required version of PSP
#				 nIdealVersion - the ideal version required to have the best results
#	Notes:		 
# ********************************************************************************
def ddjPSPVersionCheck(Environment, nRequiredVersion, nIdealVersion):
	
	# PSP current version
	Version = App.Do(Environment, 'GetVersionInfo')
	PSPVersion = Version['MajorVersion'] + 0.1 * Version['MinorVersion']
	
	# If the current version is lower than required
	if (PSPVersion < nRequiredVersion):
		App.Do( Environment, 'MsgBox', {
				'Buttons': App.Constants.MsgButtons.OK, 
				'Icon': App.Constants.MsgIcons.Stop, 
				'Text': 'This script requires Paint Shop Pro v' + str(nRequiredVersion) + ' to run. Visit http://www.corel.com to get the latest version.', 
				})
		return App.Constants.Boolean.false
	
	# The current version is at least equal to the required one
	else:
		# Is there a better version than the bare minimum?
		if (PSPVersion < nIdealVersion):
			# Quiet warning using the script debug window
			print 'This script might work better with Paint Shop Pro v%d. Visit http://www.corel.com to get the latest version.' % (nIdealVersion)
		return App.Constants.Boolean.true

# *******************************************************************************
#	Function:	 ddjIsPureRectSel
#	Purpose:	 Checks if current selection is a pure rectangle
#				 that is, rectangular shape, no feather, no antialis, no holes
#	Returns:	 True, if selection is a pure rectangle
#				 False, if selection is NOT a pure rectangle
#	Parameters:	 Environment - PSP environment
#	Notes:		This function does not check for selection
# ********************************************************************************
def ddjIsPureRectSel(Environment):
	
	# Save current selection as Alpha channel layer (name: ddjPrevSel, index: 1)
	App.Do( Environment, 'SelectSaveAlpha', {
			'SourceImage': 0,
			'AlphaName': u'ddjPrevSel',
			'Overwrite': True,
			'UpperLeft': False,
			'AlphaIndex': 1,
			'GeneralSettings': {
				'ExecutionMode': App.Constants.ExecutionMode.Default,
				'AutoActionMode': App.Constants.AutoActionMode.Match,
				'Version': ((10,0,1),1)
				}
			})

	# Generate the rectangle surrounding the current selection
	App.Do( Environment, 'ModifySelection', {
			'Selection': ((100,50), 158, 134), 
			'Type': App.Constants.SelectionModifyType.SurroundCurrent,
			'GeneralSettings': {
				'ExecutionMode': App.Constants.ExecutionMode.Default,
				'AutoActionMode': App.Constants.AutoActionMode.Match,
				'Version': ((10,0,1),1)
				}
			})

	# Remove from surrounding rectangle the selection saved as Alpha channel layer
	App.Do( Environment, 'SelectLoadAlpha', {
			'SourceImage': 0,
			'AlphaIndex': 1,
			'AlphaName': u'ddjPrevSel',
			'SelectionOperation': App.Constants.SelectionOperation.Remove,
			'UpperLeft': False,
			'ClipToCanvas': False,
			'Invert': False,
			'GeneralSettings': {
				'ExecutionMode': App.Constants.ExecutionMode.Default,
				'AutoActionMode': App.Constants.AutoActionMode.Match,
				'Version': ((10,0,1),1)
				}
			})

	# Look if there is still a selection; if so remove it
	Results = App.Do( Environment, 'ReturnImageInfo' )
	if Results['Selection'] == 0: 
		bIsPure = True
	else:
		bIsPure = False
		# SelectNone
		App.Do( Environment, 'SelectNone', {
				'GeneralSettings': {
					'ExecutionMode': App.Constants.ExecutionMode.Default, 
					'AutoActionMode': App.Constants.AutoActionMode.Match, 
					'Version': ((10,0,1),1)
					}
				})

	# Restore original selection
	App.Do( Environment, 'SelectLoadAlpha', {
			'SourceImage': 0,
			'AlphaIndex': 1,
			'AlphaName': u'ddjPrevSel',
			'SelectionOperation': App.Constants.SelectionOperation.Remove,
			'UpperLeft': False,
			'ClipToCanvas': False,
			'Invert': False,
			'GeneralSettings': {
				'ExecutionMode': App.Constants.ExecutionMode.Default,
				'AutoActionMode': App.Constants.AutoActionMode.Match,
				'Version': ((10,0,1),1)
				}
			})

	# Delete the selection from Alpha channel
	App.Do( Environment, 'DeleteAlphaChannelLayer', {
			'AllAlphas': False,
			'AlphaIndex': 1,
			'GeneralSettings': {
				'ExecutionMode': App.Constants.ExecutionMode.Default,
				'AutoActionMode': App.Constants.AutoActionMode.Match,
				'Version': ((10,0,1),1)
				}
			})

	return bIsPure
